[jboss-cvs] JBossAS SVN: r71126 - in trunk/testsuite: imports and 7 other directories.

jboss-cvs-commits at lists.jboss.org jboss-cvs-commits at lists.jboss.org
Fri Mar 21 00:49:21 EDT 2008


Author: bstansberry at jboss.com
Date: 2008-03-21 00:49:21 -0400 (Fri, 21 Mar 2008)
New Revision: 71126

Added:
   trunk/testsuite/src/main/org/jboss/test/cluster/hapartition/drm/DRMUserMBean.java
   trunk/testsuite/src/main/org/jboss/test/cluster/hapartition/ds/DistributedStateUserMBean.java
Modified:
   trunk/testsuite/build.xml
   trunk/testsuite/imports/server-config.xml
   trunk/testsuite/src/main/org/jboss/test/cluster/defaultcfg/ejb2/test/RetryInterceptorUnitTestCase.java
   trunk/testsuite/src/main/org/jboss/test/cluster/hapartition/drm/DRMUser.java
   trunk/testsuite/src/main/org/jboss/test/cluster/hapartition/ds/DistributedStateUser.java
   trunk/testsuite/src/main/org/jboss/test/cluster/multicfg/test/DRMTestCase.java
   trunk/testsuite/src/main/org/jboss/test/cluster/multicfg/test/DistributedStateTestCase.java
   trunk/testsuite/src/main/org/jboss/test/cluster/multicfg/test/HAJndiTestCase.java
   trunk/testsuite/src/resources/cluster/drm/jboss-service.xml
   trunk/testsuite/src/resources/cluster/ds/jboss-service.xml
   trunk/testsuite/src/resources/cluster/ejb2/basic/cif-jboss.xml
Log:
[JBAS-5335] Cluster testsuite HA-JNDI clients should limit autodiscovery to their partition

Modified: trunk/testsuite/build.xml
===================================================================
--- trunk/testsuite/build.xml	2008-03-21 04:47:31 UTC (rev 71125)
+++ trunk/testsuite/build.xml	2008-03-21 04:49:21 UTC (rev 71126)
@@ -71,6 +71,13 @@
    <property name="udpGroup" value=""/>
    <!-- Same thing, but passed to the client -->
    <property name="jbosstest.udpGroup" value="${udpGroup}"/>
+  
+   <!-- PartitionName -->
+   <!-- The value of the -g option passed to jboss in some configs -->
+   <!-- Override this in the local.properties or pass to Ant as -DpartitionName=FooPartition -->
+   <property name="partitionName" value="DefaultPartition"/>
+   <!-- Same thing, but passed to the client -->
+   <property name="jbosstest.partitionName" value="${partitionName}"/>
 
    <!-- =================== -->
    <!-- Basic Configuration -->

Modified: trunk/testsuite/imports/server-config.xml
===================================================================
--- trunk/testsuite/imports/server-config.xml	2008-03-21 04:47:31 UTC (rev 71125)
+++ trunk/testsuite/imports/server-config.xml	2008-03-21 04:49:21 UTC (rev 71126)
@@ -240,6 +240,7 @@
          <sysproperty key="jgroups.udp.ip_ttl" value="${jbosstest.udp.ip_ttl}" />
          <sysproperty key="jboss.messaging.ServerPeerID" value="0" />
          <sysproperty key="node0.bind.address" value="${node0}" />
+         <sysproperty key="jboss.partition.name" value="${partitionName}"/>
       </server>
       <server name="cluster-udp-1" host="${node1}">
          <jvmarg value="-Xms128m" />
@@ -252,6 +253,7 @@
          <sysproperty key="jgroups.udp.ip_ttl" value="${jbosstest.udp.ip_ttl}" />
          <sysproperty key="jboss.messaging.ServerPeerID" value="1" />
          <sysproperty key="node0.bind.address" value="${node0}" />
+         <sysproperty key="jboss.partition.name" value="${partitionName}"/>
       </server>
       <server name="cluster-field-udp-0" host="${node0}">
          <jvmarg value="-Xms128m" />
@@ -383,6 +385,7 @@
          <sysproperty key="jgroups.tcpping.initial_hosts" value="${node0}[7600],${node1}[7600]"/>
          <sysproperty key="jboss.messaging.ServerPeerID" value="0" />  
          <sysproperty key="node0.bind.address" value="${node0}" />
+         <sysproperty key="jboss.partition.name" value="${partitionName}"/>
       </server>
       <server name="cluster-tcp-1" host="${node1}">
          <jvmarg value="-Xms128m" />
@@ -396,6 +399,7 @@
          <sysproperty key="jgroups.tcpping.initial_hosts" value="${node0}[7600],${node1}[7600]"/>
          <sysproperty key="jboss.messaging.ServerPeerID" value="1" /> 
          <sysproperty key="node0.bind.address" value="${node0}" />
+         <sysproperty key="jboss.partition.name" value="${partitionName}"/>
       </server>
       <server name="cluster-tcp-sync-0" host="${node0}">
          <jvmarg value="-Xms128m" />

Modified: trunk/testsuite/src/main/org/jboss/test/cluster/defaultcfg/ejb2/test/RetryInterceptorUnitTestCase.java
===================================================================
--- trunk/testsuite/src/main/org/jboss/test/cluster/hapartition/drm/DRMUser.java	2008-03-21 04:47:31 UTC (rev 71125)
+++ trunk/testsuite/src/main/org/jboss/test/cluster/hapartition/drm/DRMUser.java	2008-03-21 04:49:21 UTC (rev 71126)
@@ -38,13 +38,15 @@
    @version $Revision$
 */
 public class DRMUser extends JBossNotificationBroadcasterSupport
-   implements IReplicants, ReplicantListener
-{
+   implements DRMUserMBean, ReplicantListener
+{   
+   private static final String DEFAULT_PARTITION_NAME = System.getProperty("jboss.partition.name", "DefaultPartition");
+   
    protected static Logger log = Logger.getLogger(DRMUser.class);
 
    protected DistributedReplicantManager drm;
    protected String category = "DRMUser";
-   protected String partitionName = "DefaultPartition";
+   protected String partitionName = DEFAULT_PARTITION_NAME;
    protected long sequence;
 
    public String getPartitionName()

Copied: trunk/testsuite/src/main/org/jboss/test/cluster/hapartition/drm/DRMUserMBean.java (from rev 71117, branches/JBPAPP_4_2_0_GA_CP/testsuite/src/main/org/jboss/test/cluster/drm/DRMUserMBean.java)
===================================================================
--- trunk/testsuite/src/main/org/jboss/test/cluster/hapartition/drm/DRMUserMBean.java	                        (rev 0)
+++ trunk/testsuite/src/main/org/jboss/test/cluster/hapartition/drm/DRMUserMBean.java	2008-03-21 04:49:21 UTC (rev 71126)
@@ -0,0 +1,37 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2008, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.test.cluster.hapartition.drm;
+
+public interface DRMUserMBean extends IReplicants
+{
+   String getPartitionName();
+
+   void setPartitionName(String partitionName);
+
+   String getCategory();
+
+   void setCategory(String category);
+   
+   void start() throws Exception;
+   
+   void stop() throws Exception;
+}
\ No newline at end of file

Modified: trunk/testsuite/src/main/org/jboss/test/cluster/hapartition/ds/DistributedStateUser.java
===================================================================
--- trunk/testsuite/src/main/org/jboss/test/cluster/hapartition/ds/DistributedStateUser.java	2008-03-21 04:47:31 UTC (rev 71125)
+++ trunk/testsuite/src/main/org/jboss/test/cluster/hapartition/ds/DistributedStateUser.java	2008-03-21 04:49:21 UTC (rev 71126)
@@ -39,7 +39,7 @@
     @version $Revision$
 */
 public class DistributedStateUser extends JBossNotificationBroadcasterSupport
-   implements IDistributedState, DSListenerEx
+   implements DistributedStateUserMBean, DSListenerEx
 {
    public static final String NOTIFY_CHANGE = "valueHasChanged";
    public static final String NOTIFY_REMOVAL = "keyHasBeenRemoved";

Copied: trunk/testsuite/src/main/org/jboss/test/cluster/hapartition/ds/DistributedStateUserMBean.java (from rev 71117, branches/JBPAPP_4_2_0_GA_CP/testsuite/src/main/org/jboss/test/cluster/ds/DistributedStateUserMBean.java)
===================================================================
--- trunk/testsuite/src/main/org/jboss/test/cluster/hapartition/ds/DistributedStateUserMBean.java	                        (rev 0)
+++ trunk/testsuite/src/main/org/jboss/test/cluster/hapartition/ds/DistributedStateUserMBean.java	2008-03-21 04:49:21 UTC (rev 71126)
@@ -0,0 +1,38 @@
+/*
+ * JBoss, Home of Professional Open Source.
+ * Copyright 2008, Red Hat Middleware LLC, and individual contributors
+ * as indicated by the @author tags. See the copyright.txt file in the
+ * distribution for a full listing of individual contributors.
+ *
+ * This is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU Lesser General Public License as
+ * published by the Free Software Foundation; either version 2.1 of
+ * the License, or (at your option) any later version.
+ *
+ * This software is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this software; if not, write to the Free
+ * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
+ */
+package org.jboss.test.cluster.hapartition.ds;
+
+public interface DistributedStateUserMBean extends IDistributedState
+{
+   public abstract String getPartitionName();
+
+   public abstract void setPartitionName(String partitionName);
+
+   public abstract String getCategory();
+
+   public abstract void setCategory(String category);
+
+   public abstract void start() throws Exception;
+
+   public abstract void stop();
+
+}
\ No newline at end of file

Modified: trunk/testsuite/src/main/org/jboss/test/cluster/multicfg/test/DRMTestCase.java
===================================================================
--- trunk/testsuite/src/main/org/jboss/test/cluster/multicfg/test/DRMTestCase.java	2008-03-21 04:47:31 UTC (rev 71125)
+++ trunk/testsuite/src/main/org/jboss/test/cluster/multicfg/test/DRMTestCase.java	2008-03-21 04:49:21 UTC (rev 71126)
@@ -49,6 +49,8 @@
  */
 public class DRMTestCase extends JBossClusteredTestCase
 {  
+   private static final String PARTITION_NAME = System.getProperty("jbosstest.partitionName", "DefaultPartition");
+   
    static class TestListener extends UnicastRemoteObject
       implements RMINotificationListener
    {
@@ -86,7 +88,7 @@
       String[] servers = super.getServers();
       RMIAdaptorExt server0 = (RMIAdaptorExt) adaptors[0];
       log.info("server0: "+server0);
-      ObjectName clusterService = new ObjectName("jboss:service=HAPartition,partition=DefaultPartition");
+      ObjectName clusterService = new ObjectName("jboss:service=HAPartition,partition=" + PARTITION_NAME);
       Vector view0 = (Vector) server0.getAttribute(clusterService, "CurrentView");
       log.info("server0: CurrentView, "+view0);
       log.debug("+++ testStateReplication 1");

Modified: trunk/testsuite/src/main/org/jboss/test/cluster/multicfg/test/DistributedStateTestCase.java
===================================================================
--- trunk/testsuite/src/main/org/jboss/test/cluster/multicfg/test/DistributedStateTestCase.java	2008-03-21 04:47:31 UTC (rev 71125)
+++ trunk/testsuite/src/main/org/jboss/test/cluster/multicfg/test/DistributedStateTestCase.java	2008-03-21 04:49:21 UTC (rev 71126)
@@ -47,6 +47,8 @@
  */
 public class DistributedStateTestCase extends JBossClusteredTestCase
 {
+   private static final String PARTITION_NAME = System.getProperty("jbosstest.partitionName", "DefaultPartition");
+   
    private static final String NOTIFY_KEY = "NotifyKey";
    private static final String NOTIFY_VALUE = "NotifyValue";
    // note - this static variable must match the category defined in ds-tests.sar
@@ -103,7 +105,7 @@
       MBeanServerConnection[] adaptors = getAdaptors();
       RMIAdaptorExt server0 = (RMIAdaptorExt) adaptors[0];
       log.info("server0: "+server0);
-      ObjectName clusterService = new ObjectName("jboss:service=HAPartition,partition=DefaultPartition");
+      ObjectName clusterService = new ObjectName("jboss:service=HAPartition,partition=" + PARTITION_NAME);
       Vector view0 = (Vector) server0.getAttribute(clusterService, "CurrentView");
       log.info("server0: CurrentView, "+view0);
       ObjectName dsService = new ObjectName("jboss.test:service=DistributedStateTestCase");

Modified: trunk/testsuite/src/main/org/jboss/test/cluster/multicfg/test/HAJndiTestCase.java
===================================================================
--- trunk/testsuite/src/resources/cluster/drm/jboss-service.xml	2008-03-21 04:47:31 UTC (rev 71125)
+++ trunk/testsuite/src/resources/cluster/drm/jboss-service.xml	2008-03-21 04:49:21 UTC (rev 71126)
@@ -5,92 +5,11 @@
 
 <server>
    <mbean code="org.jboss.test.cluster.hapartition.drm.DRMUser"
-      name="jboss.test:service=DRMTestCase"
-      xmbean-dd="">
-      <xmbean>
-         <description>DistributedReplicantManager XMBean</description>
-
-         <!-- Attributes -->
-         <attribute access="read-write" getMethod="getPartitionName" setMethod="setPartitionName">
-            <description>The cluster partition name</description>
-            <name>PartitionName</name>
-            <type>java.lang.String</type>
-            <descriptors>
-               <value value="DefaultPartition" />
-            </descriptors>
-         </attribute>
-         <attribute access="read-write" getMethod="getCategory" setMethod="setCategory">
-            <description>The category used with the DRM binding</description>
-            <name>Category</name>
-            <type>java.lang.String</type>
-            <descriptors>
-               <value value="DRMUser" />
-            </descriptors>
-         </attribute>
-
-         <!-- Operations -->
-         <operation>
-            <description>The start lifecycle operation</description>
-            <name>start</name>
-         </operation>
-         <operation>
-            <description>The stop lifecycle operation</description>
-            <name>stop</name>
-         </operation>
-
-         <operation>
-            <name>lookupLocalReplicant</name>
-            <return-type>java.io.Serializable</return-type>
-         </operation>
-         <operation>
-            <name>lookupLocalReplicant</name>
-            <parameter>
-               <name>key</name>
-               <type>java.lang.String</type>
-            </parameter>
-            <return-type>java.io.Serializable</return-type>
-         </operation>
-         <operation>
-            <name>lookupLocalReplicant</name>
-            <return-type>java.io.Serializable</return-type>
-         </operation>
-         <operation>
-            <name>lookupReplicants</name>
-            <return-type>java.util.List</return-type>
-         </operation>
-         <operation>
-            <name>lookupReplicants</name>
-            <parameter>
-               <name>key</name>
-               <type>java.lang.String</type>
-            </parameter>
-            <return-type>java.util.List</return-type>
-         </operation>
-         <operation>
-            <name>add</name>
-            <parameter>
-               <name>key</name>
-               <type>java.lang.String</type>
-            </parameter>
-            <parameter>
-               <name>data</name>
-               <type>java.io.Serializable</type>
-            </parameter>
-            <return-type>void</return-type>
-         </operation>
-         <operation>
-            <name>remove</name>
-            <parameter>
-               <name>key</name>
-               <type>java.lang.String</type>
-            </parameter>
-            <return-type>void</return-type>
-         </operation>
-      </xmbean>
-      <!-- Eliminate the depends until it's clear how to
-           depend on a microcontainer bean
-      <depends>jboss:service=DefaultPartition</depends>
-      -->
+      name="jboss.test:service=DRMTestCase">
+      
+      <attribute name="PartitionName">${jboss.partition.name:DefaultPartition}</attribute>
+      <attribute name="Category">DRMUser</attribute>
+      
    </mbean>
 
 </server>

Modified: trunk/testsuite/src/resources/cluster/ds/jboss-service.xml
===================================================================
--- trunk/testsuite/src/resources/cluster/ds/jboss-service.xml	2008-03-21 04:47:31 UTC (rev 71125)
+++ trunk/testsuite/src/resources/cluster/ds/jboss-service.xml	2008-03-21 04:49:21 UTC (rev 71126)
@@ -5,96 +5,10 @@
 
 <server>
    <mbean code="org.jboss.test.cluster.hapartition.ds.DistributedStateUser"
-      name="jboss.test:service=DistributedStateTestCase"
-      xmbean-dd="">
-      <xmbean>
-         <description>DistributedState XMBean</description>
-         <class>org.jboss.test.cluster.ds.DistributedStateUser</class>
-
-         <!-- Attributes -->
-         <attribute access="read-write" getMethod="getPartitionName" setMethod="setPartitionName">
-            <description>The cluster partition name</description>
-            <name>PartitionName</name>
-            <type>java.lang.String</type>
-            <descriptors>
-               <value value="DefaultPartition" />
-            </descriptors>
-         </attribute>
-         <attribute access="read-write" getMethod="getCategory" setMethod="setCategory">
-            <description>The category used with the DistributedState map</description>
-            <name>Category</name>
-            <type>java.lang.String</type>
-            <descriptors>
-               <value value="DistributedStateTestCase" />
-            </descriptors>
-         </attribute>
-
-         <!-- Operations -->
-         <operation>
-            <description>The start lifecycle operation</description>
-            <name>start</name>
-         </operation>
-         <operation>
-            <description>The stop lifecycle operation</description>
-            <name>stop</name>
-         </operation>
-
-         <operation>
-            <name>get</name>
-            <parameter>
-               <name>key</name>
-               <type>java.io.Serializable</type>
-            </parameter>
-            <return-type>java.io.Serializable</return-type>
-         </operation>
-         <operation>
-            <name>put</name>
-            <parameter>
-               <name>key</name>
-               <type>java.io.Serializable</type>
-            </parameter>
-            <parameter>
-               <name>value</name>
-               <type>java.io.Serializable</type>
-            </parameter>
-         </operation>
-         <operation>
-            <description>An operation that returns the current date prefixed by
-            the input argument</description>
-            <name>remove</name>
-            <parameter>
-               <name>key</name>
-               <type>java.io.Serializable</type>
-            </parameter>
-         </operation>
-         <operation>
-            <name>flush</name>
-         </operation>
-         <operation>
-            <name>size</name>
-            <return-type>int</return-type>
-         </operation>
-         <operation>
-            <name>listAllCategories</name>
-            <return-type>java.util.Collection</return-type>
-         </operation>
-         <operation>
-            <name>listAllKeys</name>
-            <parameter>
-               <name>category</name>
-               <type>java.lang.String</type>
-            </parameter>
-            <return-type>java.util.Collection</return-type>
-         </operation>
-        <operation>
-            <name>listAllValues</name>
-            <parameter>
-               <name>category</name>
-               <type>java.lang.String</type>
-            </parameter>
-            <return-type>java.util.Collection</return-type>
-         </operation>
-      </xmbean>
+      name="jboss.test:service=DistributedStateTestCase">
+      
+      <attribute name="PartitionName">${jboss.partition.name:DefaultPartition}</attribute>
+      <attribute name="Category">DistributedStateTestCase</attribute>
    </mbean>
 
 </server>

Modified: trunk/testsuite/src/resources/cluster/ejb2/basic/cif-jboss.xml
===================================================================
--- trunk/testsuite/src/resources/cluster/ejb2/basic/cif-jboss.xml	2008-03-21 04:47:31 UTC (rev 71125)
+++ trunk/testsuite/src/resources/cluster/ejb2/basic/cif-jboss.xml	2008-03-21 04:49:21 UTC (rev 71126)
@@ -9,7 +9,7 @@
          <ejb-name>cif.StatefulSession</ejb-name>
          <clustered>true</clustered>
          <cluster-config>
-            <partition-name>DefaultPartition</partition-name>
+            <partition-name>${jboss.partition.name:DefaultPartition}</partition-name>
             <home-load-balance-policy>org.jboss.ha.framework.interfaces.RandomRobin</home-load-balance-policy>
             <bean-load-balance-policy>org.jboss.ha.framework.interfaces.RoundRobin</bean-load-balance-policy>
          </cluster-config>




More information about the jboss-cvs-commits mailing list
--- trunk/testsuite/src/main/org/jboss/test/cluster/defaultcfg/ejb2/test/RetryInterceptorUnitTestCase.java	2008-03-21 04:47:31 UTC (rev 71125)
+++ trunk/testsuite/src/main/org/jboss/test/cluster/defaultcfg/ejb2/test/RetryInterceptorUnitTestCase.java	2008-03-21 04:49:21 UTC (rev 71126)
@@ -48,6 +48,7 @@
 import org.jboss.test.testbean.interfaces.EntityPK;
 import org.jboss.test.testbean.interfaces.EntityPKHome;
 import org.jboss.test.testbean.interfaces.StatefulSessionHome;
+import org.jnp.interfaces.NamingContext;
 
 /**
  * Tests the RetryInterceptor.
@@ -59,6 +60,7 @@
 {   
    private static final String DISCOVERY_TTL = System.getProperty("jbosstest.udp.ip_ttl", "1");
    private static final String DISCOVERY_GROUP = System.getProperty("jbosstest.udpGroup");
+   private static final String DISCOVERY_PARTITION = System.getProperty("jbosstest.partitionName", "DefaultPartition");
    
    protected static Logger log;
    
@@ -507,9 +509,15 @@
          // The server isn't listening on the std multicast address
          writer.write("jnp.discoveryGroup=" + DISCOVERY_GROUP);
       }
+      if (DISCOVERY_PARTITION != null && "".equals(DISCOVERY_PARTITION) == false)
+      {
+         // Limit to the partition this test environment is using
+         writer.write(NamingContext.JNP_PARTITION_NAME + "=" + DISCOVERY_PARTITION);
+      }
       writer.close();
       getLog().debug("Created custom jndi.properties at " + customJndiProperties + 
-                     " -- DISCOVERY_GROUP is " + DISCOVERY_GROUP);
+                     " -- DISCOVERY_GROUP is " + DISCOVERY_GROUP +
+                     " -- DISCOVERY_PARTITION is " + DISCOVERY_PARTITION);
       
       
       Properties env = getNamingProperties("org.jnp.interfaces.NamingContextFactory", true);
@@ -571,11 +579,19 @@
       {
          env.setProperty("jnp.disableDiscovery", "true");
       }
-      else if (DISCOVERY_GROUP != null && "".equals(DISCOVERY_GROUP) == false)
+      else
       {
-         // Use the multicast address this test environment is using
-         env.put("jnp.discoveryGroup", DISCOVERY_GROUP);
-      }
+         if (DISCOVERY_GROUP != null && "".equals(DISCOVERY_GROUP) == false)      
+         {
+            // Use the multicast address this test environment is using
+            env.put(NamingContext.JNP_DISCOVERY_GROUP, DISCOVERY_GROUP);
+         }
+         if (DISCOVERY_PARTITION != null && "".equals(DISCOVERY_PARTITION) == false)
+         {
+            // Limit to the partition this test environment is using
+            env.put(NamingContext.JNP_PARTITION_NAME, DISCOVERY_PARTITION);
+         }
+      }  
       
       return env;
    }

Modified: trunk/testsuite/src/main/org/jboss/test/cluster/hapartition/drm/DRMUser.java
===================================================================
--- trunk/testsuite/src/main/org/jboss/test/cluster/multicfg/test/HAJndiTestCase.java	2008-03-21 04:47:31 UTC (rev 71125)
+++ trunk/testsuite/src/main/org/jboss/test/cluster/multicfg/test/HAJndiTestCase.java	2008-03-21 04:49:21 UTC (rev 71126)
@@ -32,6 +32,7 @@
 import org.jboss.test.cluster.ejb2.crossserver.CalledHome;
 import org.jboss.test.cluster.ejb2.crossserver.CalledRemote;
 import org.jboss.test.JBossClusteredTestCase;
+import org.jnp.interfaces.NamingContext;
 
 /**
  * HA-JNDI clustering tests.
@@ -50,6 +51,7 @@
    private static final String NODE1_HAJNDI = System.getProperty("node1.hajndi.url");
    private static final String DISCOVERY_GROUP = System.getProperty("jbosstest.udpGroup");
    private static final String DISCOVERY_TTL = System.getProperty("jbosstest.udp.ip_ttl", "1");
+   private static final String DISCOVERY_PARTITION = System.getProperty("jbosstest.partitionName", "DefaultPartition");
    
    // BINDING SUBCONTEXT NAMES
    private static final String SUBCON1 = "subcontext1";
@@ -403,17 +405,25 @@
       env.setProperty(Context.URL_PKG_PREFIXES, "org.jboss.naming:org.jnp.interfaces");
       // Don't let the discovery packet off the test server so we don't
       // get spurious responses from other servers on the network
-      env.setProperty("jnp.discoveryTTL", DISCOVERY_TTL);
+      env.setProperty(NamingContext.JNP_DISCOVERY_TTL, DISCOVERY_TTL);
 
       if (autoDisabled)
       {
-         env.put("jnp.disableDiscovery", "true");
+         env.put(NamingContext.JNP_DISABLE_DISCOVERY, "true");
       }
-      else if (DISCOVERY_GROUP != null && "".equals(DISCOVERY_GROUP) == false)
+      else 
       {
-         // USe the multicast address this test environment is using
-         env.put("jnp.discoveryGroup", DISCOVERY_GROUP);
-      }
+         if (DISCOVERY_GROUP != null && "".equals(DISCOVERY_GROUP) == false)      
+         {
+            // Use the multicast address this test environment is using
+            env.put(NamingContext.JNP_DISCOVERY_GROUP, DISCOVERY_GROUP);
+         }
+         if (DISCOVERY_PARTITION != null && "".equals(DISCOVERY_PARTITION) == false)
+         {
+            // Limit to the partition this test environment is using
+            env.put(NamingContext.JNP_PARTITION_NAME, DISCOVERY_PARTITION);
+         }
+      }  
         
       Context naming = new InitialContext (env);
       return naming;

Modified: trunk/testsuite/src/resources/cluster/drm/jboss-service.xml
===================================================================